@@ -1,5 +1,5 @@
 try:
-    from tuneup.ndimraces import sigopt_versus_good
+    from tuneup.ndimraces import sigopt_versus_shgo_deap
 except ImportError:
     pass
 from tuneup.ndimraces import open_source_race
