@@ -12,7 +12,10 @@ def dilate(u,scale):
 
 def chop(x):
     d = decimal.Decimal(x)
-    return str(d.quantize(decimal.Decimal(".1"), decimal.ROUND_DOWN))
+    if x>100:
+        return str(round(x))
+    else:
+        return str(d.quantize(decimal.Decimal(".1"), decimal.ROUND_DOWN))
 
 def escape_bs_and_ff(s):
     return s.replace("\b", "\\b").replace("\f", "\\f")
